@@ -13,3 +13,5 @@ class Position(StrEnum):
     SHORTSTOP = "SS"
     DESIGNATED_HITTER = "DH"
     FIRST_BASEMAN = "1B"
+    CENTRE_FIELDER = "CF"
+    THIRD_BASEMAN = "3B"
