@@ -8,8 +8,6 @@ from ..espn.ncaab_espn_league_model import NCAABESPNLeagueModel
 from ..oddsportal.ncaab_oddsportal_league_model import \
     NCAABOddsPortalLeagueModel
 from ..sportsdb.ncaab_sportsdb_league_model import NCAABSportsDBLeagueModel
-from ..sportsreference.ncaab_sportsreference_league_model import \
-    NCAABSportsReferenceLeagueModel
 
 DEPAUL_BLUE_DEMONS = "DePaul Blue Demons Men's"
 GEORGETOWN_HOYAS = "Georgetown Hoyas Men's"
@@ -740,8 +738,18 @@ NCAAB_TEAM_IDENTITY_MAP: dict[str, str] = {
     "St. Thomas Tommies Men's": ST_THOMAS_TOMMIES,
     "Cal State Bakersfield Roadrunners Men's": CAL_STATE_BAKERSFIELD_ROADRUNNERS,
     "Wagner Seahawks Men's": WAGNER_SEAHAWKS,
+    # SportsDB
+    "138501": FLORIDA_GATORS,
+    "138705": HOUSTON_COUGARS,
+    "138612": DUKE_BLUE_DEVILS,
+    "138500": AUBURN_TIGERS,
+    "138772": PURDUE_FORT_WAYNE_MASTODONS,
+}
+ALAMODOME = "19330"
+NCAAB_VENUE_IDENTITY_MAP: dict[str, str] = {
+    # SportsDB
+    "19330": ALAMODOME,
 }
-NCAAB_VENUE_IDENTITY_MAP: dict[str, str] = {}
 NCAAB_PLAYER_IDENTITY_MAP: dict[str, str] = {}
 
 
@@ -753,10 +761,10 @@ class NCAABCombinedLeagueModel(CombinedLeagueModel):
             session,
             League.NCAAB,
             [
-                NCAABSportsReferenceLeagueModel(session, position=0),
-                NCAABESPNLeagueModel(session, position=1),
-                NCAABOddsPortalLeagueModel(session, position=2),
-                NCAABSportsDBLeagueModel(session, position=3),
+                NCAABESPNLeagueModel(session, position=0),
+                NCAABOddsPortalLeagueModel(session, position=1),
+                NCAABSportsDBLeagueModel(session, position=2),
+                # NCAABSportsReferenceLeagueModel(session, position=3),
             ],
             league_filter,
         )
